@@ -365,6 +365,8 @@ setup_fields (ETableConfig *config)
 {
 	int i;
 
+	e_table_model_freeze (config->available_model);
+	e_table_model_freeze (config->shown_model);
 	e_table_without_show_all (config->available_model);
 	e_table_subset_variable_clear (config->shown_model);
 
@@ -379,6 +381,8 @@ setup_fields (ETableConfig *config)
 			e_table_without_hide (config->available_model, GINT_TO_POINTER(idx));
 		}
 	}
+	e_table_model_thaw (config->available_model);
+	e_table_model_thaw (config->shown_model);
 }
 
 static void
@@ -474,6 +478,10 @@ do_fields_config_dialog (ETableConfig *config)
 {
 	int response, running = 1;
 
+	gtk_widget_ensure_style (config->dialog_show_fields);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_show_fields)->vbox), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_show_fields)->action_area), 12);
+
 	config->temp_state = e_table_state_duplicate (config->state);
 
 	setup_fields (config);
@@ -643,7 +651,7 @@ connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GC
 static gint
 get_source_model_col_index (ETableConfig *config, gint idx)
 {
-	gint visible_index, result;
+	gint visible_index;
 	ETableModel *src_model = E_TABLE_SUBSET (config->available_model)->source;
 
         visible_index = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), idx);
@@ -1148,9 +1156,8 @@ e_table_config_construct (ETableConfig        *config,
 
 	setup_gui (config);
 
-	if (parent_window)
-		gtk_window_set_transient_for (GTK_WINDOW (config->dialog_toplevel),
-					      parent_window);
+	gtk_window_set_transient_for (GTK_WINDOW (config->dialog_toplevel),
+				      parent_window);
 
 	config_sort_info_update   (config);
 	config_group_info_update  (config);
@@ -1182,6 +1189,10 @@ e_table_config_new (const char          *header,
 		return NULL;
 	}
 
+	gtk_widget_ensure_style (config->dialog_toplevel);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_toplevel)->vbox), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_toplevel)->action_area), 12);
+
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
 					   GTK_RESPONSE_APPLY, FALSE);
 	gtk_widget_show (config->dialog_toplevel);
