@@ -24,30 +24,29 @@
 #ifndef _E_TABLE_SCROLLED_H_
 #define _E_TABLE_SCROLLED_H_
 
-#include <gal/widgets/e-scroll-frame.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gal/e-table/e-table-model.h>
 #include <gal/e-table/e-table.h>
-#include <libgnome/gnome-defs.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_SCROLLED_TYPE        (e_table_scrolled_get_type ())
-#define E_TABLE_SCROLLED(o)          (GTK_CHECK_CAST ((o), E_TABLE_SCROLLED_TYPE, ETableScrolled))
-#define E_TABLE_SCROLLED_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_SCROLLED_TYPE, ETableScrolledClass))
-#define E_IS_TABLE_SCROLLED(o)       (GTK_CHECK_TYPE ((o), E_TABLE_SCROLLED_TYPE))
-#define E_IS_TABLE_SCROLLED_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_SCROLLED_TYPE))
+#define E_TABLE_SCROLLED(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_SCROLLED_TYPE, ETableScrolled))
+#define E_TABLE_SCROLLED_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_SCROLLED_TYPE, ETableScrolledClass))
+#define E_IS_TABLE_SCROLLED(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_SCROLLED_TYPE))
+#define E_IS_TABLE_SCROLLED_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_SCROLLED_TYPE))
 
 typedef struct {
-	EScrollFrame parent;
+	GtkScrolledWindow parent;
 
 	ETable *table;
 } ETableScrolled;
 
 typedef struct {
-	EScrollFrameClass parent_class;
+	GtkScrolledWindowClass parent_class;
 } ETableScrolledClass;
 
-GtkType         e_table_scrolled_get_type                  (void);
+GType           e_table_scrolled_get_type                  (void);
 
 ETableScrolled *e_table_scrolled_construct                 (ETableScrolled *ets,
 							    ETableModel    *etm,
@@ -71,7 +70,7 @@ GtkWidget      *e_table_scrolled_new_from_spec_file        (ETableModel    *etm,
 
 ETable         *e_table_scrolled_get_table                 (ETableScrolled *ets);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_SCROLLED_H_ */
 
